@@ -1,17 +1,19 @@
+# Copyright 2021 AI Singapore
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     https://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 """
-Copyright 2021 AI Singapore
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-    https://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+CLI functions for Peekingduck
 """
 
 import os
@@ -39,14 +41,14 @@ def _get_cwd() -> str:
     return os.getcwd()
 
 
-def create_custom_folder() -> None:
+def create_custom_folder(custom_folder_name: str) -> None:
     """Make custom nodes folder to create custom nodes
     """
     curdir = _get_cwd()
-    custom_node_dir = os.path.join(curdir, "src/custom_nodes")
+    custom_folder_dir = os.path.join(curdir, "src", custom_folder_name)
 
-    logger.info("Creating custom nodes folder in %s", custom_node_dir)
-    os.makedirs(custom_node_dir, exist_ok=True)
+    logger.info("Creating custom nodes folder in %s", custom_folder_dir)
+    os.makedirs(custom_folder_dir, exist_ok=True)
 
 
 def create_yml() -> None:
@@ -66,10 +68,11 @@ def create_yml() -> None:
 
 
 @cli.command()
-def init() -> None:
+@click.option('--custom_folder_name', default='custom_nodes')
+def init(custom_folder_name: str) -> None:
     """Initialise a PeekingDuck project"""
     print("Welcome to PeekingDuck!")
-    create_custom_folder()
+    create_custom_folder(custom_folder_name)
     create_yml()
 
 
@@ -84,7 +87,5 @@ def run(config_path: str) -> None:
     if not config_path:
         config_path = os.path.join(curdir, "run_config.yml")
 
-    custom_node_path = os.path.join(curdir, 'src/custom_nodes')
-
-    runner = Runner(config_path, custom_node_path)
+    runner = Runner(config_path, "src")
     runner.run()
