@@ -1,23 +1,25 @@
+# Copyright 2021 AI Singapore
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     https://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 """
-Copyright 2021 AI Singapore
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-     https://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+Reader functions for input nodes
 """
 
-from typing import Dict, Any, Union
+from typing import Any, Tuple, Union
 from threading import Thread, Lock
 import cv2
-from peekingduck.pipeline.nodes.input.utils.preprocess import set_res, mirror
+from peekingduck.pipeline.nodes.input.utils.preprocess import mirror
 
 
 class VideoThread:
@@ -25,14 +27,12 @@ class VideoThread:
     Videos will be threaded to prevent I/O blocking from affecting FPS.
     '''
 
-    def __init__(self, res: Dict[str, Any], input_source: str, mirror_image: bool) -> None:
+    def __init__(self, input_source: str, mirror_image: bool) -> None:
         self.stream = cv2.VideoCapture(input_source)
         self.mirror = mirror_image
         if not self.stream.isOpened():
             raise ValueError("Camera or video input not detected: %s" % input_source)
 
-        width, height = res['width'], res['height']
-        set_res(self.stream, width, height)
         self._lock = Lock()
 
         self.frame = None
@@ -64,21 +64,30 @@ class VideoThread:
         self._lock.release()
         return False, None
 
+    @property
+    def resolution(self) -> Tuple[int, int]:
+        """ Get resolution of the camera device used.
+
+        Returns:
+            width(int): width of input resolution
+            height(int): heigh of input resolution
+        """
+        width = self.stream.get(cv2.CAP_PROP_FRAME_WIDTH)
+        height = self.stream.get(cv2.CAP_PROP_FRAME_HEIGHT)
+        return int(width), int(height)
+
 
 class VideoNoThread:
     '''
     No threading to deal with recorded videos and images.
     '''
 
-    def __init__(self, res: Dict[str, Any], input_source: str, mirror_image: bool) -> None:
+    def __init__(self, input_source: str, mirror_image: bool) -> None:
         self.stream = cv2.VideoCapture(input_source)
         self.mirror = mirror_image
         if not self.stream.isOpened():
             raise ValueError("Video or image path incorrect: %s" % input_source)
 
-        width, height = res['width'], res['height']
-        set_res(self.stream, width, height)
-
     def __del__(self) -> None:
         self.stream.release()
 
@@ -97,3 +106,25 @@ class VideoNoThread:
         """
         fps = self.stream.get(cv2.CAP_PROP_FPS)
         return fps
+
+    @property
+    def resolution(self) -> Tuple[int, int]:
+        """ Get resolution of the file.
+
+        Returns:
+            width(int): width of resolution
+            height(int): heigh of resolution
+        """
+        width = self.stream.get(cv2.CAP_PROP_FRAME_WIDTH)
+        height = self.stream.get(cv2.CAP_PROP_FRAME_HEIGHT)
+        return int(width), int(height)
+
+    @property
+    def frame_count(self) -> int:
+        """ Get total number of frames of file
+
+        Returns:
+            int: number indicating frame count
+        """
+        num_frames = self.stream.get(cv2.CAP_PROP_FRAME_COUNT)
+        return int(num_frames)
